Learn R Programming

DyadRatios (version 1.3)

get_mood: Get Mood Estimates from Dyad Ratios Algorithm

Description

Retrieve the latent variable estimates from the dyad ratios algorithm produced by the `extract()` function.

Value

A data frame containing the period of aggregation and the corresponding latent variable estimates for each dimension.

Arguments

out

An object of class "extract", typically a result of the `extract()` function.

...

Other arguments to be passed down (currently unused).