Learn R Programming

DyadRatios (version 1.3)

jennings: Jennings Government Trust Data

Description

A dataset of survey marginals from the British Social Attitudes (BSA) survey, measuring public trust in government. These marginals are commonly used as input to the Dyad Ratios Algorithm for constructing latent time series. We replaced missing sample sizes with a value of 850, which is roughly the minimum sample size observed in the data.

Arguments

Format

A data frame with 4 variables and `r nrow(jennings)` rows:

variable

Character string identifying the survey question or series.

date

Date the survey was fielded.

value

percentage of people indicating distrust in the government.

n

Sample size for the survey wave.

Examples

Run this code
data(jennings)
head(jennings)

Run the code above in your browser using DataLab