Retrieve the latent variable estimates from the dyad ratios algorithm produced by the `extract()` function.
A data frame containing the period of aggregation and the corresponding latent variable estimates for each dimension.
An object of class "extract", typically a result of the `extract()` function.
Other arguments to be passed down (currently unused).